@@ -21,25 +21,32 @@
 //#define DEBUG_SHOPPER 1
 #include "notify.h"
 #include "shopper.h"           // automake, i8n, gettext
-#include <QMessageBox>
 
 namespace Shopper
 {
 	// class Notify : public QSystemTrayIcon
-	Notify::Notify(const QIcon & icon) :
-		QSystemTrayIcon(icon)
+	Notify::Notify(const QIcon & icon)
+#ifndef Q_OS_FREMANTLE
+		: QSystemTrayIcon(icon)
+#endif
 	{}
 
-	void Notify::showMessage ( const QString & title, const QString & message, MessageIcon icon, int millisecondsTimeoutHint )
+	void Notify::showMessage ( const QString & title, const QString & message,
+//							   MessageIcon icon,
+							   int millisecondsTimeoutHint )
 	{
-		if (supportsMessages()) {
+#ifndef Q_OS_FREMANTLE
+	if (supportsMessages()) {
 			DEBUG("supportsMessages");
 			QSystemTrayIcon::showMessage(title, message, icon, millisecondsTimeoutHint );
 		} else {
+#endif
 			QMessageBox msgBox;
 			msgBox.setText(title);
 			msgBox.setInformativeText(message);
 			msgBox.exec();
+#ifndef Q_OS_FREMANTLE
 		}
+#endif
 	}
 }
